@@ -1,9 +1,9 @@
 """
 View, modify your gists.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Gists:
     """
     View, modify your gists.
@@ -11,22 +11,17 @@ class Gists:
 
     def __init__(self, client):
         """
-        Initialize the Gists class.
+        Initializes the Gists class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_gists_for_the_authenticated_user(self, params=None, payload=None):
         """
+        Summary:
         List gists for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/gists#list-gists-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        since
-         per-page
-         page
         """
         url = self._base_url + "/gists"
         response = self._execute("get", url, params=params, payload=payload)
@@ -34,13 +29,10 @@ class Gists:
 
     def create_a_gist(self, params=None, payload=None):
         """
+        Summary:
         Create a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#create-a-gist
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/gists"
         response = self._execute("post", url, params=params, payload=payload)
@@ -48,15 +40,10 @@ class Gists:
 
     def list_public_gists(self, params=None, payload=None):
         """
+        Summary:
         List public gists
+        Docs:
         https://docs.github.com/rest/reference/gists#list-public-gists
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        since
-         per-page
-         page
         """
         url = self._base_url + "/gists/public"
         response = self._execute("get", url, params=params, payload=payload)
@@ -64,15 +51,10 @@ class Gists:
 
     def list_starred_gists(self, params=None, payload=None):
         """
+        Summary:
         List starred gists
+        Docs:
         https://docs.github.com/rest/reference/gists#list-starred-gists
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        since
-         per-page
-         page
         """
         url = self._base_url + "/gists/starred"
         response = self._execute("get", url, params=params, payload=payload)
@@ -80,13 +62,10 @@ class Gists:
 
     def get_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Get a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#get-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -94,13 +73,10 @@ class Gists:
 
     def update_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Update a gist
+        Docs:
         https://docs.github.com/rest/reference/gists/#update-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -108,13 +84,10 @@ class Gists:
 
     def delete_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Delete a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#delete-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -122,14 +95,10 @@ class Gists:
 
     def list_gist_comments(self, gist_id, params=None, payload=None):
         """
+        Summary:
         List gist comments
+        Docs:
         https://docs.github.com/rest/reference/gists#list-gist-comments
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/gists/{gist_id}/comments"
         response = self._execute("get", url, params=params, payload=payload)
@@ -137,13 +106,10 @@ class Gists:
 
     def create_a_gist_comment(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Create a gist comment
+        Docs:
         https://docs.github.com/rest/reference/gists#create-a-gist-comment
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/comments"
         response = self._execute("post", url, params=params, payload=payload)
@@ -151,14 +117,10 @@ class Gists:
 
     def get_a_gist_comment(self, gist_id, comment_id, params=None, payload=None):
         """
+        Summary:
         Get a gist comment
+        Docs:
         https://docs.github.com/rest/reference/gists#get-a-gist-comment
-        Attributes:
-        Path Parameters:
-        gist_id
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -166,14 +128,10 @@ class Gists:
 
     def update_a_gist_comment(self, gist_id, comment_id, params=None, payload=None):
         """
+        Summary:
         Update a gist comment
+        Docs:
         https://docs.github.com/rest/reference/gists#update-a-gist-comment
-        Attributes:
-        Path Parameters:
-        gist_id
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -181,14 +139,10 @@ class Gists:
 
     def delete_a_gist_comment(self, gist_id, comment_id, params=None, payload=None):
         """
+        Summary:
         Delete a gist comment
+        Docs:
         https://docs.github.com/rest/reference/gists#delete-a-gist-comment
-        Attributes:
-        Path Parameters:
-        gist_id
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -196,14 +150,10 @@ class Gists:
 
     def list_gist_commits(self, gist_id, params=None, payload=None):
         """
+        Summary:
         List gist commits
+        Docs:
         https://docs.github.com/rest/reference/gists#list-gist-commits
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/gists/{gist_id}/commits"
         response = self._execute("get", url, params=params, payload=payload)
@@ -211,14 +161,10 @@ class Gists:
 
     def list_gist_forks(self, gist_id, params=None, payload=None):
         """
+        Summary:
         List gist forks
+        Docs:
         https://docs.github.com/rest/reference/gists#list-gist-forks
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/gists/{gist_id}/forks"
         response = self._execute("get", url, params=params, payload=payload)
@@ -226,13 +172,10 @@ class Gists:
 
     def fork_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Fork a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#fork-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/forks"
         response = self._execute("post", url, params=params, payload=payload)
@@ -240,13 +183,10 @@ class Gists:
 
     def check_if_a_gist_is_starred(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Check if a gist is starred
+        Docs:
         https://docs.github.com/rest/reference/gists#check-if-a-gist-is-starred
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/star"
         response = self._execute("get", url, params=params, payload=payload)
@@ -254,13 +194,10 @@ class Gists:
 
     def star_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Star a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#star-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/star"
         response = self._execute("put", url, params=params, payload=payload)
@@ -268,13 +205,10 @@ class Gists:
 
     def unstar_a_gist(self, gist_id, params=None, payload=None):
         """
+        Summary:
         Unstar a gist
+        Docs:
         https://docs.github.com/rest/reference/gists#unstar-a-gist
-        Attributes:
-        Path Parameters:
-        gist_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/star"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -282,14 +216,10 @@ class Gists:
 
     def get_a_gist_revision(self, gist_id, sha, params=None, payload=None):
         """
+        Summary:
         Get a gist revision
+        Docs:
         https://docs.github.com/rest/reference/gists#get-a-gist-revision
-        Attributes:
-        Path Parameters:
-        gist_id
-        sha
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gists/{gist_id}/{sha}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -297,15 +227,10 @@ class Gists:
 
     def list_gists_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List gists for a user
+        Docs:
         https://docs.github.com/rest/reference/gists#list-gists-for-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        since
-         per-page
-         page
         """
         url = self._base_url + f"/users/{username}/gists"
         response = self._execute("get", url, params=params, payload=payload)
