@@ -1,9 +1,9 @@
 """
 Raw Git functionality.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Git:
     """
     Raw Git functionality.
@@ -11,21 +11,17 @@ class Git:
 
     def __init__(self, client):
         """
-        Initialize the Git class.
+        Initializes the Git class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def create_a_blob(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a blob
+        Docs:
         https://docs.github.com/rest/reference/git#create-a-blob
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/blobs"
         response = self._execute("post", url, params=params, payload=payload)
@@ -33,15 +29,10 @@ class Git:
 
     def get_a_blob(self, owner, repo, file_sha, params=None, payload=None):
         """
+        Summary:
         Get a blob
+        Docs:
         https://docs.github.com/rest/reference/git#get-a-blob
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        file_sha
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/blobs/{file_sha}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -49,14 +40,10 @@ class Git:
 
     def create_a_commit(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a commit
+        Docs:
         https://docs.github.com/rest/reference/git#create-a-commit
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/commits"
         response = self._execute("post", url, params=params, payload=payload)
@@ -64,15 +51,10 @@ class Git:
 
     def get_a_commit(self, owner, repo, commit_sha, params=None, payload=None):
         """
+        Summary:
         Get a commit
+        Docs:
         https://docs.github.com/rest/reference/git#get-a-commit
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        commit_sha
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/commits/{commit_sha}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -80,16 +62,10 @@ class Git:
 
     def list_matching_references(self, owner, repo, ref, params=None, payload=None):
         """
+        Summary:
         List matching references
+        Docs:
         https://docs.github.com/rest/reference/git#list-matching-references
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        ref
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/matching-refs/{ref}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -97,15 +73,10 @@ class Git:
 
     def get_a_reference(self, owner, repo, ref, params=None, payload=None):
         """
+        Summary:
         Get a reference
+        Docs:
         https://docs.github.com/rest/reference/git#get-a-reference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        ref
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/ref/{ref}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -113,47 +84,21 @@ class Git:
 
     def create_a_reference(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a reference
+        Docs:
         https://docs.github.com/rest/reference/git#create-a-reference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/refs"
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_all_references_in_a_namespace(self, owner, repo, namespace, params=None, payload=None):
-        """
-        Get all references in a namespace
-        https://docs.github.com/rest/reference/git#get-a-reference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        namespace
-        Payload Parameters:
-        per-page
-         page
-        """
-        url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{namespace}"
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
     def update_a_reference(self, owner, repo, ref, params=None, payload=None):
         """
+        Summary:
         Update a reference
+        Docs:
         https://docs.github.com/rest/reference/git#update-a-reference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        ref
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{ref}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -161,15 +106,10 @@ class Git:
 
     def delete_a_reference(self, owner, repo, ref, params=None, payload=None):
         """
+        Summary:
         Delete a reference
+        Docs:
         https://docs.github.com/rest/reference/git#delete-a-reference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        ref
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{ref}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -177,14 +117,10 @@ class Git:
 
     def create_a_tag_object(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a tag object
+        Docs:
         https://docs.github.com/rest/reference/git#create-a-tag-object
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/tags"
         response = self._execute("post", url, params=params, payload=payload)
@@ -192,15 +128,10 @@ class Git:
 
     def get_a_tag(self, owner, repo, tag_sha, params=None, payload=None):
         """
+        Summary:
         Get a tag
+        Docs:
         https://docs.github.com/rest/reference/git#get-a-tag
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        tag_sha
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/tags/{tag_sha}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -208,14 +139,10 @@ class Git:
 
     def create_a_tree(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a tree
+        Docs:
         https://docs.github.com/rest/reference/git#create-a-tree
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/trees"
         response = self._execute("post", url, params=params, payload=payload)
@@ -223,15 +150,10 @@ class Git:
 
     def get_a_tree(self, owner, repo, tree_sha, params=None, payload=None):
         """
+        Summary:
         Get a tree
+        Docs:
         https://docs.github.com/rest/reference/git#get-a-tree
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        tree_sha
-        Payload Parameters:
-        recursive
         """
         url = self._base_url + f"/repos/{owner}/{repo}/git/trees/{tree_sha}"
         response = self._execute("get", url, params=params, payload=payload)
