@@ -1,4 +1,6 @@
 """
 Init for file for meta package.
 """
-from .meta import Meta  # noqa: F401
+# flake8: noqa
+
+from .meta import Meta
