@@ -1,33 +1,27 @@
 """
 Move projects to or from GitHub.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Migrations:
-    # pylint: disable=too-many-public-methods
     """
     Move projects to or from GitHub.
     """
 
     def __init__(self, client):
         """
-        Initialize the Migrations class.
+        Initializes the Migrations class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_organization_migrations(self, org, params=None, payload=None):
         """
+        Summary:
         List organization migrations
+        Docs:
         https://docs.github.com/rest/reference/migrations#list-organization-migrations
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        per-page
-         page
-         exclude
         """
         url = self._base_url + f"/orgs/{org}/migrations"
         response = self._execute("get", url, params=params, payload=payload)
@@ -35,13 +29,10 @@ class Migrations:
 
     def start_an_organization_migration(self, org, params=None, payload=None):
         """
+        Summary:
         Start an organization migration
+        Docs:
         https://docs.github.com/rest/reference/migrations#start-an-organization-migration
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/migrations"
         response = self._execute("post", url, params=params, payload=payload)
@@ -49,14 +40,10 @@ class Migrations:
 
     def get_an_organization_migration_status(self, org, migration_id, params=None, payload=None):
         """
+        Summary:
         Get an organization migration status
+        Docs:
         https://docs.github.com/rest/reference/migrations#get-an-organization-migration-status
-        Attributes:
-        Path Parameters:
-        org
-        migration_id
-        Payload Parameters:
-        exclude
         """
         url = self._base_url + f"/orgs/{org}/migrations/{migration_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -66,14 +53,10 @@ class Migrations:
         self, org, migration_id, params=None, payload=None
     ):
         """
+        Summary:
         Download an organization migration archive
+        Docs:
         https://docs.github.com/rest/reference/migrations#download-an-organization-migration-archive
-        Attributes:
-        Path Parameters:
-        org
-        migration_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/archive"
         response = self._execute("get", url, params=params, payload=payload)
@@ -83,14 +66,10 @@ class Migrations:
         self, org, migration_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete an organization migration archive
+        Docs:
         https://docs.github.com/rest/reference/migrations#delete-an-organization-migration-archive
-        Attributes:
-        Path Parameters:
-        org
-        migration_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/archive"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -100,15 +79,10 @@ class Migrations:
         self, org, migration_id, repo_name, params=None, payload=None
     ):
         """
+        Summary:
         Unlock an organization repository
+        Docs:
         https://docs.github.com/rest/reference/migrations#unlock-an-organization-repository
-        Attributes:
-        Path Parameters:
-        org
-        migration_id
-        repo_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/repos/{repo_name}/lock"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -118,15 +92,10 @@ class Migrations:
         self, org, migration_id, params=None, payload=None
     ):
         """
+        Summary:
         List repositories in an organization migration
+        Docs:
         https://docs.github.com/rest/reference/migrations#list-repositories-in-an-organization-migration
-        Attributes:
-        Path Parameters:
-        org
-        migration_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/repositories"
         response = self._execute("get", url, params=params, payload=payload)
@@ -134,14 +103,10 @@ class Migrations:
 
     def get_an_import_status(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get an import status
+        Docs:
         https://docs.github.com/rest/reference/migrations#get-an-import-status
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import"
         response = self._execute("get", url, params=params, payload=payload)
@@ -149,14 +114,10 @@ class Migrations:
 
     def start_an_import(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Start an import
+        Docs:
         https://docs.github.com/rest/reference/migrations#start-an-import
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import"
         response = self._execute("put", url, params=params, payload=payload)
@@ -164,14 +125,10 @@ class Migrations:
 
     def update_an_import(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Update an import
+        Docs:
         https://docs.github.com/rest/reference/migrations#update-an-import
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -179,14 +136,10 @@ class Migrations:
 
     def cancel_an_import(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Cancel an import
+        Docs:
         https://docs.github.com/rest/reference/migrations#cancel-an-import
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -194,14 +147,10 @@ class Migrations:
 
     def get_commit_authors(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get commit authors
+        Docs:
         https://docs.github.com/rest/reference/migrations#get-commit-authors
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        since-user
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import/authors"
         response = self._execute("get", url, params=params, payload=payload)
@@ -209,15 +158,10 @@ class Migrations:
 
     def map_a_commit_author(self, owner, repo, author_id, params=None, payload=None):
         """
+        Summary:
         Map a commit author
+        Docs:
         https://docs.github.com/rest/reference/migrations#map-a-commit-author
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        author_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import/authors/{author_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -225,14 +169,10 @@ class Migrations:
 
     def get_large_files(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get large files
+        Docs:
         https://docs.github.com/rest/reference/migrations#get-large-files
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import/large_files"
         response = self._execute("get", url, params=params, payload=payload)
@@ -240,14 +180,10 @@ class Migrations:
 
     def update_git_lfs_preference(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Update Git LFS preference
+        Docs:
         https://docs.github.com/rest/reference/migrations#update-git-lfs-preference
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/import/lfs"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -255,14 +191,10 @@ class Migrations:
 
     def list_user_migrations(self, params=None, payload=None):
         """
+        Summary:
         List user migrations
+        Docs:
         https://docs.github.com/rest/reference/migrations#list-user-migrations
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + "/user/migrations"
         response = self._execute("get", url, params=params, payload=payload)
@@ -270,13 +202,10 @@ class Migrations:
 
     def start_a_user_migration(self, params=None, payload=None):
         """
+        Summary:
         Start a user migration
+        Docs:
         https://docs.github.com/rest/reference/migrations#start-a-user-migration
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/user/migrations"
         response = self._execute("post", url, params=params, payload=payload)
@@ -284,13 +213,10 @@ class Migrations:
 
     def get_a_user_migration_status(self, migration_id, params=None, payload=None):
         """
+        Summary:
         Get a user migration status
+        Docs:
         https://docs.github.com/rest/reference/migrations#get-a-user-migration-status
-        Attributes:
-        Path Parameters:
-        migration_id
-        Payload Parameters:
-        exclude
         """
         url = self._base_url + f"/user/migrations/{migration_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -298,13 +224,10 @@ class Migrations:
 
     def download_a_user_migration_archive(self, migration_id, params=None, payload=None):
         """
+        Summary:
         Download a user migration archive
+        Docs:
         https://docs.github.com/rest/reference/migrations#download-a-user-migration-archive
-        Attributes:
-        Path Parameters:
-        migration_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/migrations/{migration_id}/archive"
         response = self._execute("get", url, params=params, payload=payload)
@@ -312,13 +235,10 @@ class Migrations:
 
     def delete_a_user_migration_archive(self, migration_id, params=None, payload=None):
         """
+        Summary:
         Delete a user migration archive
+        Docs:
         https://docs.github.com/rest/reference/migrations#delete-a-user-migration-archive
-        Attributes:
-        Path Parameters:
-        migration_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/migrations/{migration_id}/archive"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -326,14 +246,10 @@ class Migrations:
 
     def unlock_a_user_repository(self, migration_id, repo_name, params=None, payload=None):
         """
+        Summary:
         Unlock a user repository
+        Docs:
         https://docs.github.com/rest/reference/migrations#unlock-a-user-repository
-        Attributes:
-        Path Parameters:
-        migration_id
-        repo_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/migrations/{migration_id}/repos/{repo_name}/lock"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -341,14 +257,10 @@ class Migrations:
 
     def list_repositories_for_a_user_migration(self, migration_id, params=None, payload=None):
         """
+        Summary:
         List repositories for a user migration
+        Docs:
         https://docs.github.com/rest/reference/migrations#list-repositories-for-a-user-migration
-        Attributes:
-        Path Parameters:
-        migration_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/user/migrations/{migration_id}/repositories"
         response = self._execute("get", url, params=params, payload=payload)
