@@ -1,4 +1,6 @@
 """
 Init for file for teams package.
 """
-from .teams import Teams  # noqa: F401
+# flake8: noqa
+
+from .teams import Teams
