@@ -1,5 +1,5 @@
 """
-This module containst the RestClient class.
+This module contains the RestClient class.
 """
 
 import os
@@ -18,6 +18,8 @@ class RestClientError(Exception):
 class RestClient:
     # pylint: disable=too-few-public-methods
     # pylint: disable=too-many-instance-attributes
+    # pylint: disable=too-many-statements
+    # pylint: disable=duplicate-code
     """
     The following methods are used to form requests to the GitHub REST API.
     """
@@ -25,23 +27,22 @@ class RestClient:
     def __init__(self, hostname=None, api_token=None):
         """
         Initialize the REST client to make requests to the GitHub API.
-
         Attributes:
-            headers (dict): Headers to be used in the requests.
-            base_url (str): Base URL of the GitHub API.
-            API_TOKEN (str): GitHub API token.
-            REST_API_URL (str): GitHub REST API URL.
+            api_token (str): GitHub API token.
+            hostname (str): GitHub URL Slug (only needed if using GHES).
         """
         if api_token is None:
             api_token = os.environ.get("API_TOKEN")
             if os.environ.get("API_TOKEN") is None:
                 raise RestClientError("API_TOKEN environment variable is not set")
         self._headers = {"Authorization": f"Bearer {api_token}"}
-
-        hostname = os.environ.get("GHE_HOSTNAME")
         if hostname is None:
-            rest_api_url = "https://api.github.com"
-        else:
+            hostname = os.environ.get("GHE_HOSTNAME")
+            if os.environ.get("GHE_HOSTNAME") is None:
+                rest_api_url = "https://api.github.com"
+            else:
+                rest_api_url = "https://" + hostname + "/api/v3"
+        elif hostname:
             rest_api_url = "https://" + hostname + "/api/v3"
 
         self._base_url = rest_api_url
@@ -64,10 +65,9 @@ class RestClient:
         self.issues = apis.issues.Issues(self)
         self.licenses = apis.licenses.Licenses(self)
         self.markdown = apis.markdown.Markdown(self)
+        self.merge_queue = apis.merge_queue.MergeQueue(self)
         self.meta = apis.meta.Meta(self)
         self.migrations = apis.migrations.Migrations(self)
-        self.oauth_authorizations = apis.oauth_authorizations.OauthAuthorizations(self)
-        self.oidc = apis.oidc.Oidc(self)
         self.orgs = apis.orgs.Orgs(self)
         self.packages = apis.packages.Packages(self)
         self.projects = apis.projects.Projects(self)
@@ -75,13 +75,12 @@ class RestClient:
         self.rate_limit = apis.rate_limit.RateLimit(self)
         self.reactions = apis.reactions.Reactions(self)
         self.repos = apis.repos.Repos(self)
-        self.scim = apis.scim.Scim(self)
         self.search = apis.search.Search(self)
         self.secret_scanning = apis.secret_scanning.SecretScanning(self)
         self.server_statistics = apis.server_statistics.ServerStatistics(self)
         self.teams = apis.teams.Teams(self)
         self.users = apis.users.Users(self)
-        print("URL: ", rest_api_url)
+        print("REST API URL:", rest_api_url)
 
     def paginate_request(self, response):
         """
